pub trait FieldExt: Field { }Expand description
Extension trait for ff::Field, intended as a place to put optimizable arithmetic operations.
The idea is future versions of this crate can add provided methods which are useful in dense
field arithmetic like primeorder’s RCB implementation, and primefield can potentially
automatically plug in optimized implementations when available.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.